@@ -249,7 +249,13 @@ class Tweeper {
       return NULL;
     }
 
-    return Tweeper::jsonToXml($matches[1], 'instagram');
+    // The "qe" object contains elements which will result in invalid XML
+    // element names, so remove it.
+    $data = json_decode($matches[1], $assoc = TRUE);
+    unset($data["qe"]);
+    $json = json_encode($data);
+
+    return Tweeper::jsonToXml($json, 'instagram');
   }
 
   /**
